from setuptools import setup

setup(name='python_knowledge',
      version='0.1',
      description='knowledge about python for students',
      packages=['python_knowledge'],
      author_email='bloodruslan@gmail.com',
      zip_safe=False)
